@@ -33,7 +33,7 @@ import zipfile
 
 from distutils.version import LooseVersion
 
-__version__ = "0.21.0"
+__version__ = "0.21.2"
 
 is_windows = os.name == "nt"
 
@@ -168,6 +168,7 @@ library."""
         "c_header": False,
         "include_source": False,
         "has_source": True,
+        "both_analyzers": False,
     }
     d["uc_name"] = d["name"].upper().replace("-", "_")
     if d["type_id"] != "e":
@@ -186,6 +187,8 @@ library."""
         d["include_source"] = True
     if d["type_id"] == "h":
         d["has_source"] = False
+    if d["use_clang_tidy"] and d["use_cppcheck"]:
+        d["both_analyzers"] = True
     d["c_header"] = d["c"] and d["type_id"] == "h"
     return d
 
